package lutadebonecos;

import JPlay.Sprite;

/**
 * @author Gefersom Cardoso Lima
 * Universidade Federal Fluminense - UFF - Brasil - 2010
 * Ciência da Computação
 */

public class Boneco extends Sprite
{
    //Usamos essa variável, pois quando o boneco pára de se locomover perdemos
    //qual era o lado para qual o mesmo estava se locomovendo.
    private char sentidoAnterior; // e - esquerda ; d - direita

    public Boneco(String caminho)
    {
            super(caminho, 28);
            setTimeChangeFrame(70);
            setVelocityX(2);

            sentidoAnterior = Sprite.STOP;
            setFloor(500);
            setCurrFrame(3);
    }

    public void setarSpritesSentidoLocomocao()
    {

            //Retorna em qual sentido o boneco está se locomovendo,
            //Se é para a esquerda ou para a direita.
            char sentido = getStateOfX();

            //Verifica se o boneco está se locomovendo para a esquerda.
            //Se a condição que envolve um 'ou' não existisse enquanto o usurário
            //estivesse pressionando a seta para a esquerda, os frames para a esquerda iriam
            //sempre ser setados. Isso geraria algumas incoerências na animação.
            //Para entender melhor, experimente retirar a segunda condição, deixe somente
            //a condição sentido == Sprite.LEFT.
            //Se antes estavamos parado ou andando, então, podemos trocar os frames
            //que serão exibidos na tela, caso contrário, os frames já teriam sido trocados
            //e não há necessidade de haver uma nova troca de frames.
            if (sentido == Sprite.LEFT &&
                     (sentidoAnterior == Sprite.STOP || sentidoAnterior == Sprite.RIGHT) )
            {
                    setRangeOfFrames(0, 13);
                    sentidoAnterior = Sprite.LEFT;
            }
            else
            {
                    //Frames correspondentes ao andar para a direita.
                    //Faz a mesma coisa que o primeiro if, só dessa vez testa se o
                    //boneco se locomove para a direita.
                    if( ( sentido == Sprite.RIGHT ) &&
                         (sentidoAnterior == Sprite.LEFT || sentidoAnterior == Sprite.STOP) )
                        {
                                setRangeOfFrames(14, 27);
                                sentidoAnterior = Sprite.RIGHT;
                        }
                    else
                    {
                        //No lugar do código não comentado abaixo, poderíamos usar
                        //o código seguinte comentado, mas usando este, quando
                        //o boneco parasse de se movimentar o frame que estivesse sendo
                        //exibido no momento da parada iria continuar a ser exibido.
                        //Se for uma frame que mostre o boneco correndo ele irá continuar
                        //a ser exibido.
                        //    if (sentido == Sprite.STOP)
                        //        sentidoAnterior = Sprite.STOP;

                        //Se o boneco está parado entra no if
                        if (sentido == Sprite.STOP)
                        {
                                //Verifica se o sentido anterior que o boneco se
                                //locomovia era o da direita, e seta um frame que
                                //deixa o boneco virado para a direita.
                                if (sentidoAnterior == Sprite.RIGHT)
                                    setCurrFrame(17);
                                else
                                {
                                    //Verifica se o sentido anterior que o boneco
                                    //se locomovia era o da esuqerda, e seta um
                                    //frame que deixa o boneco virado para a esquerda.
                                    if (sentidoAnterior == Sprite.LEFT)
                                        setCurrFrame(3);
                                }
                        }
                    }
            }

            //Se o boneco não está parado então pode rodar a animação
            if (sentido != STOP) runAnimation();           
    }

    public char getSentido()
    {
            return sentidoAnterior;
    }
}

